==> am_mod_blg_0_1.zip: am_mod_blg_0_1/components/blg/template/barnraiser_01/list.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<form action="index.php?amn=blg_list" method="post" name="frm" id="id_frm">
<input type="hidden" name="blog_id" value="<?php if(isset($blog['blog_id'])) { echo $blog['blog_id'];}?>" />

<div class="col_main">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_list'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($blogs)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td valign="top">
						<b><?php echo $lang['txt_blog'];?></b>: <a href="index.php?amn=blg_item&amp;blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_title'];?></a><br />
					</td>
					<td valign="top">
						<b><?php echo $lang['txt_entry'];?></b>:
						<a href="index.php?amn=blg_item&amp;entry_id=<?php echo $i['entry_id'];?>"><?php echo $i['entry_title'];?></a><br />
					</td>
				</tr>
				<tr>
					<td valign="top" colspan="2">
						<a href="index.php?amn=blg_item&amp;entry_id=<?php echo $i['entry_id'];?>"><b><?php echo $this->date->formatDate($i['entry_create_datetime'],1);?></b></a>
						<?php echo $i['entry_body'];?><br />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				
				<?php
				}
				elseif (isset($entries)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($entries as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=blg_item&amp;entry_id=<?php echo $i['entry_id'];?>"><?php echo $i['entry_title'];?></a><br />
						<?php echo $i['entry_synopsis'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				
				<?php
				}
				elseif (isset($tags)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($tags as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=blg_item&amp;entry_id=<?php echo $i['entry_id'];?>"><?php echo $i['entry_title'];?></a><br />
						<?php echo $i['entry_synopsis'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				}
				elseif (isset($display) && $display == 'intro') {
				?>
					<p>
						<?php echo $lang['txt_search_intro'];?><br />
					</p>
				<?php
				}
				else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_search'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<input type="text" name="search_text" value="<?php if(isset($_POST['search_text'])) { echo $_POST['search_text'];};?>" class="input1" /><br />
				</p>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="search" class="input_submit" value="<?php echo $lang['sub_search']; ?>" /><br />
				</p>
			</div>
		</div>
	</div>
</div>
</form>

==> am_mod_blg_0_4.zip: am_mod_blg_0_4/components/blg/template/barnraiser_01/list.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<form action="index.php?amn=blg_list" method="post" name="frm" id="id_frm">
<input type="hidden" name="blog_id" value="<?php if(isset($blog['blog_id'])) { echo $blog['blog_id'];}?>" />

<div class="col_main">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_list'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($blogs)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td valign="top">
						<b><?php echo $lang['txt_blog'];?></b>: <a href="index.php?amn=blg_item&amp;blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_title'];?></a><br />
					</td>
					<td valign="top">
						<b><?php echo $lang['txt_entry'];?></b>:
						<a href="index.php?amn=blg_item&amp;entry_id=<?php echo $i['entry_id'];?>"><?php echo $i['entry_title'];?></a><br />
					</td>
				</tr>
				<tr>
					<td valign="top" colspan="2">
						<a href="index.php?amn=blg_item&amp;entry_id=<?php echo $i['entry_id'];?>"><b><?php echo $this->date->formatDate($i['entry_create_datetime'],1);?></b></a>
						<?php echo $i['entry_body'];?><br />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				
				<?php
				}
				elseif (isset($entries)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($entries as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=blg_item&amp;entry_id=<?php echo $i['entry_id'];?>"><?php echo $i['entry_title'];?></a><br />
						<?php echo $i['entry_synopsis'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				
				<?php
				}
				elseif (isset($tags)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($tags as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=blg_item&amp;entry_id=<?php echo $i['entry_id'];?>"><?php echo $i['entry_title'];?></a><br />
						<?php echo $i['entry_synopsis'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				}
				elseif (isset($display) && $display == 'intro') {
				?>
					<p>
						<?php echo $lang['txt_search_intro'];?><br />
					</p>
				<?php
				}
				else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_search'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<input type="text" name="search_text" value="<?php if(isset($_POST['search_text'])) { echo $_POST['search_text'];};?>" class="input1" /><br />
				</p>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="search" class="input_submit" value="<?php echo $lang['sub_search']; ?>" /><br />
				</p>
			</div>
		</div>
	</div>
</div>
</form>
